/* interface for text events
	93/11/05 created */

#include "EventLib.h"
#include "MathLib.h"
#include "TextLib.h"

static EventTableType gEventTable;
	
static Boolean menu(EventObjectType object, const MenuPickType *pick)
{
	Boolean handled;
	
	handled = TxMenu(object, pick);	
	if (handled && pick->cmd != CMD_SELECT_ALL)
		TxSelectionShow(object);
	return(handled);
}

static void adjustmenu(EventObjectType object)
{
	TxAdjustMenu(object);
}

static TicksType adjustsleep(EventObjectType object)
{
	return TxAdjustSleep(object);
}

static void idle(EventObjectType object)
{
	TxIdle(object);
}

static Boolean within(EventObjectType object, Point where)
{
	return TxWithin(object, where);
}

static Boolean mousedown(EventObjectType object, EventRecord *event)
{
	FocusSet(object);
	TxMouseDown(object, event);
	return(true);
}

static void keydown(EventObjectType object, EventRecord *event)
{
	TxKey(object, event->message);
	TxSelectionShow(object);
}

static void selectall(EventObjectType object)
{
	TxSelectAll(object);
}

static void update(EventObjectType object)
{
	TxUpdate(object);
}

static void focus(EventObjectType object, Boolean focus)
{
	TxFocus(object, focus);
}

static void activate(EventObjectType object, Boolean active)
{
	TxActivate(object, active);
}

static void zoom(EventObjectType object, short *width, short *height)
{
	TextHandle text = object;
	
	*width = min(TxWidthAll(text), SHRT_MAX);
	*height = min(TxHeightAll(text), SHRT_MAX);
	FrameZoom((**text).frame, width, height);
}

static void resize(EventObjectType object, short dh, short dv)
{
	TxResize(object, dh, dv);
}

static void suspend(void)
{
	TxScrapToDeskScrap();
}

static void resume(void)
{
	TxScrapFromDeskScrap();
}

const /* EventTableType */ void *TxEventTable(void)
{
	return(&gEventTable);
}

void TxEventTableRegister(void)
{
	gEventTable.focusObject.idle = idle;
	gEventTable.focusObject.keydown = keydown;
	gEventTable.focusObject.menu = menu;
	gEventTable.focusObject.adjustmenu = adjustmenu;
	gEventTable.focusWindow.adjustsleep = adjustsleep;
	gEventTable.focusWindow.within = within;
	gEventTable.focusWindow.mousedown = mousedown;
	gEventTable.focusWindow.selectall = selectall;
	gEventTable.focusWindow.focus = focus;
	gEventTable.window.zoom = zoom;
	gEventTable.window.resize = resize;
	gEventTable.window.update = update;
	gEventTable.window.activate = activate;
	gEventTable.objectType.suspend = suspend;
	gEventTable.objectType.resume = resume;
	EventTableRegister(&gEventTable);
}
